#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-code-range-plugin-2.3.0.0-7iPETOtVP5OKlqnzU4SdOJ
key:                  hls-code-range-plugin-2.3.0.0-7iPETOtVP5OKlqnzU4SdOJ
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c9dea0015dfa4a2dece5d7501e4bcaff
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.3.0.0-7iPETOtVP5OKlqnzU4SdOJ
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-H98LN7RYlKwJ5W6Qh2fTke
    ghcide-2.3.0.0-JmXEOQnhfiKAxpmfuuBYnH
    hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw
    hls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
    lens-5.3.5-AYBI3DxVlEzIh1R399daMf
    lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0 mtl-2.3.1
    semigroupoids-6.0.2-FGGtTtqt6rV2cvhDg8aBc5 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-7HrFQCkgeKZFLrimW7Ifgg

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

